### Name: acf
### Title: Auto- and Cross- Covariance and -Correlation Function Estimation
### Aliases: acf ccf pacf pacf.default [.acf
### Keywords: ts

### ** Examples

## Examples from Venables & Ripley
acf(lh)
acf(lh, type = "covariance")
pacf(lh)

acf(ldeaths)
acf(ldeaths, ci.type = "ma")
acf(ts.union(mdeaths, fdeaths))
ccf(mdeaths, fdeaths, ylab="cross-correlation") # just the cross-correlations.

presidents # contains missing values
acf(presidents, na.action = na.pass)
pacf(presidents, na.action = na.pass)



